==> comptechsoft-vue-foundation-1.0.6.tgz: package/src/~compvuetech/Classes/Axios/Fetcher/~AxiosFetcher.example.js <==
/**
 * AxiosFetcher. Clasa pentru extragere de date din tabele
 */
import AxiosFetcher from './AxiosFetcher';

let axios = new AxiosFetcher()

    /**
     * Callback pentru success 
     */
    .OnSuccess( () => {
        console.log(axios.response)
        console.log('----')
        console.log('Current page > '+ axios.current_page)
        console.log('Per page > '+ axios.per_page)
        console.log('Records > ', axios.records)
        console.log('Total-From-To-Last page > ' + axios.total + '-' + axios.record_count + '-'  + axios.from + '-' + axios.to + '-' + axios.last_page)
    })

    /**
     * Endpoint
     */
    .SetEndpoint('admin/roles/fetch')
    
    /**
     * Pagina curenta
     */
    .SetCurrentPage(3)

    /**
     * Cate inregistrari pe pagina
     */
    .SetPerPage(7)

    /**
     * Pe ce campuri se face Quick Search 
     */
    .SetSearchFields(['roles.name', 'roles.slug'])

    /**
     * Coloanele care permit sortare
     */
    .AddOrderColumn('name', ['roles.name'])
    .AddOrderColumn('slug', ['roles.slug'])
    .AddOrderColumn('users_count', ['users_count'])
    
    /**
     * Coloanele care permit conditions (filtrari)
     */
    .AddCondition('name', 'roles.name', 'string')
    .AddCondition('id', 'roles.id', 'integer')

    /**
     * Criterii de filtrare permanente
     */
    .AddFilter('(roles.id >= :min:) AND (roles.id <= :max:)',{
        min: 5,
        max: 40, 
    })

/**
 * Extragerea datelor
 */
axios.Refresh()

setTimeout( () => {
    /**
     * Filtrare dupa o condition
     */
    axios.Condition('name', 'end', {value: 'j'})
}, 1000)

setTimeout( () => {
    /**
     * Cautare dupa un text
     */
    axios.Search('*kj')
}, 2000)

setTimeout( () => {
    /**
     * Sortarea dupa o coloana
     */
    axios.Order('name', 'asc')
}, 3000)

==> comptechsoft-vue-foundation-1.0.10.tgz: package/src/~compvuetech/Classes/Axios/Fetcher/~AxiosFetcher.example.js <==
/**
 * AxiosFetcher. Clasa pentru extragere de date din tabele
 */
import AxiosFetcher from './AxiosFetcher';

let axios = new AxiosFetcher()

    /**
     * Callback pentru success 
     */
    .OnSuccess( () => {
        console.log(axios.response)
        console.log('----')
        console.log('Current page > '+ axios.current_page)
        console.log('Per page > '+ axios.per_page)
        console.log('Records > ', axios.records)
        console.log('Total-From-To-Last page > ' + axios.total + '-' + axios.record_count + '-'  + axios.from + '-' + axios.to + '-' + axios.last_page)
    })

    /**
     * Endpoint
     */
    .SetEndpoint('admin/roles/fetch')
    
    /**
     * Pagina curenta
     */
    .SetCurrentPage(3)

    /**
     * Cate inregistrari pe pagina
     */
    .SetPerPage(7)

    /**
     * Pe ce campuri se face Quick Search 
     */
    .SetSearchFields(['roles.name', 'roles.slug'])

    /**
     * Coloanele care permit sortare
     */
    .AddOrderColumn('name', ['roles.name'])
    .AddOrderColumn('slug', ['roles.slug'])
    .AddOrderColumn('users_count', ['users_count'])
    
    /**
     * Coloanele care permit conditions (filtrari)
     */
    .AddCondition('name', 'roles.name', 'string')
    .AddCondition('id', 'roles.id', 'integer')

    /**
     * Criterii de filtrare permanente
     */
    .AddFilter('id', '(roles.id >= :min:) AND (roles.id <= :max:)',{
        min: 5,
        max: 40, 
    })

/**
 * Extragerea datelor
 */
axios.Refresh()

setTimeout( () => {
    /**
     * Filtrare dupa o condition
     */
    axios.Condition('name', 'end', {value: 'j'})
}, 1000)

setTimeout( () => {
    /**
     * Cautare dupa un text
     */
    axios.Search('*kj')
}, 2000)

setTimeout( () => {
    /**
     * Sortarea dupa o coloana
     */
    axios.Order('name', 'asc')
}, 3000)
